==> gaphor-2.6.5.tar.gz: gaphor-2.6.5/gaphor/UML/classes/enumerationpropertypages.py <==
from gi.repository import Gtk

from gaphor import UML
from gaphor.core.format import format
from gaphor.diagram.propertypages import (
    PropertyPageBase,
    PropertyPages,
    on_text_cell_edited,
)
from gaphor.transaction import transactional
from gaphor.UML.classes.classespropertypages import (
    AttributesPage,
    ClassEnumerationLiterals,
    OperationsPage,
    new_builder,
    on_keypress_event,
)
from gaphor.UML.classes.enumeration import EnumerationItem


@PropertyPages.register(EnumerationItem)
class EnumerationPage(PropertyPageBase):
    """An editor for enumeration literals for an enumeration."""

    order = 20

    def __init__(self, item):
        super().__init__()
        self.item = item
        self.watcher = item.subject and item.subject.watcher()

    def construct(self):
        if not isinstance(self.item.subject, UML.Enumeration):
            return

        builder = new_builder("enumerations-editor")
        page = builder.get_object("enumerations-editor")

        show_enumerations = builder.get_object("show-enumerations")
        show_enumerations.set_active(self.item.show_enumerations)

        self.model = ClassEnumerationLiterals(self.item)

        tree_view: Gtk.TreeView = builder.get_object("enumerations-list")
        tree_view.set_model(self.model)

        def handler(event):
            enumeration = event.element
            for row in self.model:
                if row[-1] is enumeration:
                    row[:] = [format(enumeration), enumeration]

        self.watcher.watch("ownedLiteral.name", handler)

        builder.connect_signals(
            {
                "show-enumerations-changed": (self._on_show_enumerations_change,),
                "enumerations-name-edited": (on_text_cell_edited, self.model, 0),
                "tree-view-destroy": (self.watcher.unsubscribe_all,),
                "enumerations-keypress": (on_keypress_event,),
            }
        )
        return page

    @transactional
    def _on_show_enumerations_change(self, button, gparam):
        self.item.show_attributes = button.get_active()
        self.item.request_update()


PropertyPages.register(EnumerationItem)(AttributesPage)
PropertyPages.register(EnumerationItem)(OperationsPage)

==> gaphor-2.7.0.tar.gz: gaphor-2.7.0/gaphor/UML/classes/enumerationpropertypages.py <==
from gi.repository import Gtk

from gaphor import UML
from gaphor.core.format import format
from gaphor.diagram.propertypages import (
    PropertyPageBase,
    PropertyPages,
    on_text_cell_edited,
)
from gaphor.transaction import transactional
from gaphor.UML.classes.classespropertypages import (
    AttributesPage,
    ClassEnumerationLiterals,
    OperationsPage,
    new_resource_builder,
    on_keypress_event,
)
from gaphor.UML.classes.enumeration import EnumerationItem

new_builder = new_resource_builder("gaphor.UML.classes")


@PropertyPages.register(EnumerationItem)
class EnumerationPage(PropertyPageBase):
    """An editor for enumeration literals for an enumeration."""

    order = 20

    def __init__(self, item):
        super().__init__()
        self.item = item
        self.watcher = item.subject and item.subject.watcher()

    def construct(self):
        if not isinstance(self.item.subject, UML.Enumeration):
            return

        self.model = ClassEnumerationLiterals(self.item)

        builder = new_builder(
            "enumerations-editor",
            signals={
                "show-enumerations-changed": (self._on_show_enumerations_change,),
                "enumerations-name-edited": (on_text_cell_edited, self.model, 0),
                "tree-view-destroy": (self.watcher.unsubscribe_all,),
            },
        )

        show_enumerations = builder.get_object("show-enumerations")
        show_enumerations.set_active(self.item.show_enumerations)

        tree_view: Gtk.TreeView = builder.get_object("enumerations-list")
        tree_view.set_model(self.model)

        if Gtk.get_major_version() == 3:
            controller = self.key_controller = Gtk.EventControllerKey.new(tree_view)
        else:
            controller = Gtk.EventControllerKey.new()
            tree_view.add_controller(controller)
        controller.connect("key-pressed", on_keypress_event, tree_view)

        def handler(event):
            enumeration = event.element
            for row in self.model:
                if row[-1] is enumeration:
                    row[:] = [format(enumeration), enumeration]

        self.watcher.watch("ownedLiteral.name", handler)

        return builder.get_object("enumerations-editor")

    @transactional
    def _on_show_enumerations_change(self, button, gparam):
        self.item.show_enumerations = button.get_active()
        self.item.request_update()


PropertyPages.register(EnumerationItem)(AttributesPage)
PropertyPages.register(EnumerationItem)(OperationsPage)
